# Table Collection

Table Collection commands are used to create dynamic table types and tables.

## Creat table collections for Assembly

```{eval-rst}
.. autoclass:: abaqus.TableCollection.TableCollectionAssembly.TableCollectionAssembly
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

## Creat table collections for Model

```{eval-rst}
.. autoclass:: abaqus.TableCollection.TableCollectionModel.TableCollectionModel
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

## Other Classes

```{eval-rst}

.. toggle::

    .. automembers:: abaqus.TableCollection
        :recursive:
        :exclude: TableCollectionAssembly, TableCollectionModel
```
